/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0
 */
package com.topcoder.file.statistics;

import java.io.File;

/**
 * <summary> StatsReporting interface defines the contract to aggregate and render the statistical report. Result
 * is fed into this interface one by one and the file report is then generated. There is a way to reset (clear) the
 * current aggregated results. </summary>
 *
 * <contract-constructor> All implementation should have a constructor with a Property as an argument in order to
 * reflect from configuration file. This requirement can be dropped if it's not necessary to use this way.
 * </contract-constructor>
 *
 * <thread-safety> There is no thread-safety requirement/recommendation for the implementations. </thread-safety>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public interface StatsReporting {

    /**
     * <summary> Aggregate the result into the reporting implementation. The results are kept by the reporting
     * itself. </summary>
     *
     * @param processor the processor that generated the result
     * @param file the file that is processed
     * @param result the processing result
     *
     * @throws NullPointerException if any argument is null
     * @throws StatsReportingException if file is not in base dir
     */
    public void aggregate(FileProcessor processor, File file, StatsResult result) throws StatsReportingException;

    /**
     * <summary> Generate the report with all the aggregated results. </summary>
     *
     * @return the generated report
     * @throws StatsReportingException if error occurs
     */
    public String generateReport() throws StatsReportingException;

    /**
     * <summary> Clear all the aggregated result and set the base dir (which is nullable). </summary>
     *
     * @param baseDirectory the base dir to reset
     *
     * @throws IllegalArgumentException if baseDirectory is not null and not a valid dir
     */
    public void reset(File baseDirectory);

}
