/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0
 */
package com.topcoder.file.statistics.matcher;

import java.io.File;

import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.util.config.Property;

/**
 * <summary> AnyFileMatcher is a trivial implementation that matches any file. </summary>
 *
 * <configuration> Does not need any configuration. Constructor maintained for reflection purpose. </configuration>
 *
 * <thread-safety> This class is stateless and thread-safe. </thread-safety>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class AnyFileMatcher implements FileMatcher {

    /**
     * <summary> Default constructor. Does nothing. </summary>
     */
    public AnyFileMatcher() {
        // empty
    }

    /**
     * <summary> Reflection contract. Does nothing. </summary>
     *
     * @param property the property to configure from
     * @throws NullPointerException if property is null
     */
    public AnyFileMatcher(Property property) {
        CheckHelper.checkNull(property, "property");
    }

    /**
     * <summary> Simply return true. </summary>
     *
     * @return true
     * @param file the file to match
     *
     * @throws NullPointerException if file is null
     */
    public boolean match(File file) {
        CheckHelper.checkNull(file, "file");
        return true;
    }

}
