/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 *
 * TCS File Statistics 1.0 (Unit Test)
 */
package com.topcoder.file.statistics.matcher;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

/**
 * <p>Unit test case for FileCategoryMatcher abstract class. </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class FileCategoryMatcherTests extends TestCase {

    /** A concrete subclass of FileCategoryMatcher which behaves like binary file matcher. */
    private static final class MyFileMatcher extends FileCategoryMatcher {

        /**
         * <summary> Decide whether the file category matches. </summary>
         *
         * @return whether the category matches
         * @param isBinary whether the file is binary
         */
        protected boolean match(boolean isBinary) {
            return isBinary;
        }

    }

    /** The matcher instance that is tested. */
    private static final FileCategoryMatcher MATCHER = new MyFileMatcher();

    /**
     * Creation test for FileCategoryMatcher default constructor.
     */
    public void testFileCategoryFileMatcher1() {
        new MyFileMatcher();
        // nothing to verify
    }

    /**
     * Tests match method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException to JUnit
     */
    public void testMatch1() throws IOException {
        try {
            MATCHER.match(null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Tests match(File) method with non-null argument. True should be returned, if the file is binary according to
     * the algorithm of method FileCategoryMatcher.isBinary(File).
     *
     * @throws IOException to JUnit
     */
    public void testMatch2() throws IOException {
        assertTrue("binary file should be matched", MATCHER.match(new File("test_files/a/p.zip")));
        assertFalse("text file should not be matched", MATCHER.match(new File("test_files/a/p.txt")));
        assertFalse("empty file should not be matched", MATCHER.match(new File("test_files/a/empty.txt")));
    }

    /**
     * Tests match(File) method with non-existing file. IOException should be thrown.
     */
    public void testMatch3() {
        try {
            MATCHER.match(new File("test_files/not_exists"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

    /**
     * Tests match(File) method with a directory file. IOException should be thrown.
     */
    public void testMatch4() {
        try {
            MATCHER.match(new File("test_files/p/"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

    /**
     * Tests isBinary method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException to JUnit
     */
    public void testIsBinary1() throws IOException {
        try {
            FileCategoryMatcher.isBinary(null);
            fail("NullPointerException should be thrown.");
        } catch (NullPointerException e) {
            // ok
        }
    }

    /**
     * Tests isBinary(File) method with non-null argument. True should be returned, if the file is a recognized to
     * be a binary file.
     *
     * @throws IOException to JUnit
     */
    public void testIsBinary2() throws IOException {
        assertTrue("binary file should be matched", FileCategoryMatcher.isBinary(new File("test_files/a/p.zip")));
        assertFalse("text file should not be matched", FileCategoryMatcher
                .isBinary(new File("test_files/a/p.txt")));
        assertFalse("empty file should not be matched", FileCategoryMatcher.isBinary(new File(
                "test_files/a/empty.txt")));
    }

    /**
     * Tests isBinary method with non-existing file. IOException should be thrown.
     */
    public void testIsBinary3() {
        try {
            FileCategoryMatcher.isBinary(new File("test_files/not_exists"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

    /**
     * Tests isBinary method with a directory file. IOException should be thrown.
     */
    public void testIsBinary4() {
        try {
            FileCategoryMatcher.isBinary(new File("test_files/p/"));
            fail("IOException should be thrown.");
        } catch (IOException e) {
            // ok
        }
    }

}
